# Features/fixes

Describe new features or bugs fixed.

# Related issues (optional)

Add links to issues related to this pull request, if any.

# Mentions

Mention team members responsible for reviewing this change. 

# Checklist

Have you...
- [ ] Formatted your code properly adhering to PEP-8? Considering using RUFF to format your code automatically.
- [ ] Resolved all merge conflicts with the main branch?
- [ ] Checked the diffs between your branch and the main branch to ensure that your changes are not introducing any regressions or unnecessary/irrelevant changes?
